"""
Raw data for faker_music module (music.py) to mine from.
Data is presented in one big list of dicts, each dict
corresponding to a "instrument object":
{
    "category": "<category>",
    "instruments": [
        "<instrument1>",
        "<instrument2>",
        "<instrument3>",
        ...
    ]
}

This data was harvested on 2021-05-20, from 
https://en.wikipedia.org/wiki/List_of_musical_instruments
Author maintains code to format copy/pasted data;
please ask for link to gist
"""

instrument_list = [
    {
        "category": "percussion",
        "instruments": [
            "Aburukuwa",
            "Acme siren",
            "Afoxé",
            "Agogô",
            "Agung",
            "Agung a tamlang",
            "Alarm device",
            "Alfaia",
            "Alligator drum",
            "Angklung",
            "Anvil",
            "Apito",
            "Ashiko",
            "Atabaque",
            "Babendil",
            "Bak",
            "Balafon",
            "Bamboula",
            "Bara",
            "Bass drum",
            "Batá drum",
            "Beatboxing",
            "Bedug",
            "Bell",
            "Bell plate",
            "Bell tree",
            "Bendir",
            "Berimbau",
            "Bianzhong",
            "Binzasara",
            "Bo",
            "Bock-a-da-bock",
            "Bodhrán",
            "Body percussion",
            "Bombo criollo",
            "Bombo legüero",
            "Bonang",
            "Bones (instrument)",
            "Bongo drum",
            "Boobam",
            "Boomwhacker",
            "Bougarabou",
            "Bubon",
            "Buk",
            "Cabasa",
            "Cajón",
            "Cajón de rumba",
            "Calung",
            "Carimbo",
            "Candombe drums",
            "Cannon",
            "Cantaro",
            "Carillon",
            "Castanets",
            "Caxirola",
            "Caxixi",
            "Celesta",
            "Chácaras",
            "Chenda",
            "Chime bar",
            "Chime (bell instrument)",
            "China cymbal",
            "Cimbalom",
            "Clapper",
            "Clapping",
            "Clap stick",
            "Clash cymbals",
            "Claves",
            "Clavichord",
            "Clay drum",
            "Cocktail drum",
            "Conga",
            "Cowbell",
            "Crotale",
            "Crystallophone",
            "Cuíca",
            "Cup chime",
            "Cymbal",
            "Dabakan",
            "Daf",
            "Damaru",
            "Damphu",
            "Đàn tam thập lục",
            "Davul",
            "Daxophone",
            "Dayereh",
            "Den-den daiko",
            "Derkach",
            "Dhaa",
            "Dhimay",
            "Dholak",
            "Dhol",
            "Dimdi",
            "Djembe",
            "Dohol",
            "Dollu",
            "Đông Sơn drums",
            "Drum",
            "Drum stick",
            "Dunun",
            "Egg shaker",
            "Ekwe",
            "Electronic drum",
            "Esterilla",
            "Ferrinho",
            "Fiddlesticks",
            "Finger snapping",
            "Flexatone",
            "Flower drum",
            "Fontomfrom",
            "Found object",
            "Frame drum",
            "Friction drum",
            "Galgo",
            "Gandingan",
            "Ganzá",
            "Gbedu",
            "Gendèr",
            "Geophone",
            "Ghatam",
            "Glasschord",
            "Glass harmonica",
            "Glass harp",
            "Glockenspiel",
            "Goblet drum",
            "Goema",
            "Gong",
            "Gong bass drum",
            "Gonguê",
            "Gudugudu",
            "Güira",
            "Güiro",
            "Hammered dulcimer",
            "Handbell",
            "Handchime",
            "Hand-repique",
            "Handpan",
            "Hang",
            "Hi-hat",
            "Hosho",
            "Huiringua",
            "Hydraulophone",
            "Hyoshigi",
            "Igba",
            "Ikembe",
            "Ikoro",
            "Ilimba",
            "Jam block",
            "Janggu / Janggo / Changgo",
            "Jawbone",
            "Jaw harp",
            "Jhallari",
            "Jingle",
            "Junjung",
            "Kakko",
            "Kanjira",
            "Karyenda",
            "Kebero",
            "Kecer",
            "Kemanak",
            "Kempyang and ketuk",
            "Kendang",
            "Kenong",
            "Kepyak",
            "Keyboard glockenspiel",
            "Khim",
            "Khol",
            "Kirikoketa",
            "Kiringi",
            "Kisanji",
            "Klong khaek",
            "Klong yao",
            "Kouxian",
            "Kpanlogo",
            "Kulintang",
            "Kundu",
            "Kus",
            "Lambeg",
            "Lion's roar",
            "Lithophone",
            "Lujon",
            "Lummi stick",
            "Madal",
            "Maddale",
            "Madhalam",
            "Maktoum",
            "Makuta",
            "Malimbe",
            "Mangey",
            "Maraca",
            "Maram (drum)",
            "Marching machine",
            "Marfa",
            "Marimba",
            "Marímbula",
            "Mark tree",
            "Mbira",
            "Metallophone",
            "Mirwas",
            "Monkey stick",
            "Mridangam",
            "Musical saw",
            "Nagara",
            "Naqara",
            "Naqareh",
            "Naqus",
            "Ngoma drums",
            "North Drums",
            "Ocean drum",
            "Octa-Vibraphone",
            "Octoban",
            "Omele",
            "Onavillu",
            "Ōtsuzumi",
            "Padayani thappu",
            "Pahu",
            "Pahū pounamu",
            "Paiban",
            "Paila criolla",
            "Pakhavaj",
            "Pambai",
            "Pandeiro",
            "Pandero jarocho",
            "Pantalon",
            "Pellet drum",
            "Pixiphone",
            "Practice pad",
            "Plasmaphone",
            "Pyrophone",
            "Quadrangularis Reversum",
            "Quintephone",
            "Rainstick",
            "Rakatak",
            "Ranat ek",
            "Ranat ek lek",
            "Ranat thum",
            "Ranat thum lek",
            "Ratchet",
            "Rattle",
            "Ravanne",
            "Rebana",
            "Repique",
            "Ring of bells",
            "Ring-repique",
            "Ringing rocks",
            "Riq",
            "Rock gong",
            "Rototom",
            "Sabar",
            "Sakara",
            "Salterio",
            "Sambal",
            "Samphor",
            "Sand blocks",
            "Santoor",
            "Santur",
            "Saron",
            "Scabellum",
            "Semantron",
            "Shekere",
            "Shime-daiko",
            "Shishi-odoshi",
            "Shōko",
            "Sikulu",
            "Silex Piano",
            "Singing bowl",
            "Siren (alarm)",
            "Skrabalai",
            "Skull",
            "Sleigh bells",
            "Slenthem",
            "Slit drum",
            "Snare drum",
            "Song bells",
            "Sounding stone",
            "Spoon",
            "Steelpan",
            "Stomp box",
            "Stone marimba",
            "Suikinkutsu",
            "Surdo",
            "Suspended cymbal",
            "Taal",
            "Tabla",
            "Tabla tarang",
            "Taiko",
            "Talempong",
            "Talking drum",
            "Tambora",
            "Tamborim",
            "Tamborita calentana",
            "Tambourine",
            "Tan-tan",
            "Tap shoe",
            "Taphon",
            "Tar (drum)",
            "Tassa",
            "Taxi Horn",
            "Tbilat",
            "Teponaztli",
            "Thappu",
            "Thavil",
            "Thunder machine (instrument)",
            "Thunder sheet",
            "Tifa (drum)",
            "Timbal",
            "Timbales",
            "Timpani",
            "Tingsha",
            "Tom-tom drum",
            "Tombak",
            "Triangle",
            "Triccaballacca",
            "Tsuzumi",
            "Tsymbaly",
            "Tubular bells",
            "Tumba",
            "Turntable",
            "Tumdak'",
            "Turkish crescent",
            "Txalaparta",
            "Udu",
            "Vibraphone",
            "Vibraslap",
            "Washboard",
            "Whip",
            "Whistle",
            "Wind chime",
            "Wind machine",
            "Wobble board",
            "Wood block",
            "Wooden fish",
            "Xylophone",
            "Xylorimba",
            "Yangqin",
            "Yuka",
            "Zabumba",
            "Zatula",
            "Zill",
        ],
    },
    {
        "category": "winds",
        "instruments": [
            "Accordina (instrument)",
            "Accordion",
            "Accordola",
            "Air horn",
            "Alboka",
            "Algaita",
            "Alphorn",
            "Alto horn",
            "Arghul",
            "Atenteben",
            "Aulos",
            "Bagpipe",
            "Balaban",
            "Bandoneón",
            "Bansuri",
            "Baritone horn",
            "Baritone voice",
            "Bassoon",
            "Bawu",
            "Bayan",
            "Bazooka",
            "Beatboxing",
            "Bifora",
            "Birbynė",
            "Blul",
            "Blown bottle",
            "Bombarde",
            "Buccina",
            "Bugle",
            "Bullroarer",
            "Calliope",
            "Castrato",
            "Chalumeau",
            "Cimbasso",
            "Clarinet",
            "Clarytone",
            "Concertina",
            "Conch",
            "Cornamuse",
            "Cornet",
            "Cornett",
            "Cornu",
            "Corrugaphone",
            "Countertenor",
            "Cromorne",
            "Crumhorn",
            "Danso",
            "Death growl",
            "Didgeridoo",
            "Diple (or dvojnice)",
            "Dizi",
            "Double bell euphonium",
            "Doulophone/cuprophone",
            "Duduk",
            "Dulcian",
            "Dulzaina",
            "Dung-Dkar",
            "Dzhamara",
            "English horn",
            "Euphonium",
            "Falsetto",
            "Fife",
            "Firebird (trumpet)",
            "Fiscorn",
            "Flabiol",
            "Flageolet",
            "Flatt trumpet",
            "Flugelhorn",
            "Flumpet",
            "Flutina",
            "Flute",
            "Folgerphone",
            "French horn",
            "Fujara",
            "Gaida",
            "Gaita gastoreña",
            "Garmon",
            "Gemshorn",
            "Gralla",
            "Guan",
            "Guanzi",
            "Houguan",
            "Hano",
            "Harmoneon",
            "Harmonica",
            "Harmonium",
            "Heckelphone",
            "English horn",
            "Helicon",
            "Horagai",
            "Hosaphone",
            "Hotchiku",
            "Hulusi",
            "Hun",
            "Inci",
            "Irish flute",
            "Jug",
            "Kagurabue",
            "Kalaleng",
            "Kaval",
            "Kazoo",
            "Kèn bầu",
            "Key bugle",
            "Khene",
            "Khloy",
            "Khlui",
            "Komabue",
            "Koncovka",
            "Kortholt",
            "Koudi",
            "Kuhlohorn",
            "Launeddas",
            "Livenka",
            "Lur",
            "Lusheng",
            "Lituus",
            "Mellophone",
            "Melodica",
            "Melodeon",
            "Mezzo-soprano",
            "Mijwiz",
            "Mizmar",
            "Mizwad",
            "Musette de cour",
            "Nadaswaram",
            "Nagak",
            "Natural trumpet",
            "Ney",
            "Nguru",
            "Nohkan",
            "Nose flute",
            "Nplooj",
            "Nulophone",
            "Oboe",
            "aerophones",
            "Ocarina",
            "Octavin",
            "Ophicleide",
            "Paixiao",
            "Palendag",
            "Pan flute",
            "Pasiyak or water whistle",
            "Pavari",
            "Pibgorn",
            "Picco pipe",
            "Piccolo",
            "Piccolo trumpet",
            "Pipe organ",
            "Pitch pipe",
            "Pocket cornet",
            "Pocket trumpet",
            "Post horn",
            "Pu",
            "Pulalu",
            "Qeej",
            "Quena",
            "Quinticlave",
            "Raj",
            "Rackett",
            "Ralé-poussé",
            "Rapping",
            "Rauschpfeife",
            "Recorder",
            "Garklein",
            "Sopranino",
            "Descant",
            "Treble or alto",
            "Tenor",
            "Bass",
            "Great bass",
            "Contra bass",
            "Subcontra bass",
            "Sub-subcontrabass",
            "Venova",
            "Reed contrabass",
            "Reed organ",
            "Rhaita",
            "Robero",
            "Roman tuba",
            "Ryuteki",
            "Sac de gemecs",
            "Sackbut",
            "Saenghwang",
            "Samponia",
            "Saratovskaya garmonika",
            "Sarrusophone",
            "Saxophone",
            "Saxhorn",
            "Saxotromba",
            "Saxtuba",
            "Scat singing",
            "Schwyzerörgeli",
            "Serpent",
            "Shakuhachi",
            "Shankha",
            "Shawm",
            "Shehnai",
            "Sheng",
            "Shinobue",
            "Shofar",
            "Shō",
            "Shvi",
            "Siku",
            "Siren",
            "Slide trumpet",
            "Sneng",
            "Sodina",
            "Sopila",
            "Soprano",
            "Sorna",
            "Sousaphone",
            "Sralai",
            "Sudrophone",
            "Suling",
            "Suona",
            "Laba",
            "Haidi",
            "Superbone",
            "Swordblade",
            "Tabor pipe",
            "Taepyeongso",
            "Tarogato",
            "Tenor",
            "Tenora",
            "Throat singing",
            "Tible",
            "Tin whistle",
            "Toasting",
            "Tonette",
            "Trikiti",
            "Trombone",
            "Tromboon",
            "Trompeta china",
            "Trumpet",
            "Tuba",
            "Tube trumpet",
            "Tumpong",
            "Tungso",
            "Tutek",
            "Txistu",
            "Uilleann pipes",
            "Venu",
            "Vibrandoneon",
            "Vienna horn",
            "Vocal percussion",
            "Vuvuzela",
            "Wagner tuba",
            "Washint",
            "Flute",
            "Whip",
            "Pea whistle",
            "Steam whistle",
            "Train whistle",
            "Willow flute",
            "Xeremia",
            "Xiao",
            "Xun",
            "Yodel",
            "Yotar",
            "Yu",
            "Zhaleika",
            "Zufolo",
            "Zugtrompette",
            "Zurna",
            "Surnay",
        ],
    },
    {
        "category": "strings",
        "instruments": [
            "Adungu",
            "Aeolian harp",
            "Ajaeng",
            "Akkordolia",
            "Algerian mandole",
            "Angélique",
            "Appalachian dulcimer",
            "Arbajo",
            "Archlute",
            "Arpeggione",
            "Autoharp",
            "Bağlama",
            "Bajo sexto",
            "Balalaika",
            "Bandola",
            "Bandolin",
            "Bandolón",
            "Bandura",
            "Bandora",
            "Bandurria",
            "Banhu",
            "Banjo",
            "Banjo ukulele",
            "Barbat",
            "Baryton",
            "Berimbau",
            "Bipa",
            "Biwa",
            "Bordonua",
            "Bouzouki",
            "Buzuq",
            "Carimba",
            "Cavaquinho",
            "Cello",
            "Chapman stick",
            "Charangos",
            "Chitarra battente",
            "Chitarra Italiana",
            "Choghur",
            "Cimbalom",
            "Electric cymbalum",
            "Cimboa",
            "Citole",
            "Cittern",
            "Clavichord",
            "Clavinet",
            "Concheras",
            "Contraguitar",
            "Crwth (Crowd)",
            "Cuatro",
            "Cümbüş",
            "Đàn bầu",
            "Đàn đáy",
            "Đàn gáo",
            "Đàn nguyệt",
            "Đàn tam thập lục",
            "Đàn tranh",
            "Đàn tỳ bà",
            "Diddley bow",
            "Dihu",
            "Dombra",
            "Domra",
            "Doshpuluur",
            "Dotara",
            "Double bass",
            "Dreadnought",
            "Dulcimer",
            "Dutar",
            "Duxianqin",
            "Ektara",
            "Erhu",
            "Erxian",
            "Esraj",
            "Faglong/Fuglung",
            "Fegereng",
            "Fiddle",
            "Gaohu",
            "Gayageum",
            "Geomungo",
            "Gittern",
            "Gottuvadhyam",
            "Guitars",
            "Gusli",
            "Guqin",
            "Guzheng",
            "Haegeum",
            "Hammered dulcimer",
            "Hardanger fiddle",
            "Harmonico",
            "Harp",
            "Harpsichord",
            "Hegelong",
            "Huapanguera",
            "Huluhu",
            "Huqin",
            "Hurdy-gurdy",
            "Igil",
            "Irish bouzouki",
            "Janzi",
            "Jarana jarocho",
            "Jarana huasteca",
            "Jarana mosquito",
            "Jarana segunda",
            "Jarana tercera",
            "Jiaohu",
            "Kabosy",
            "Kadlong",
            "Kamancha",
            "Kantele",
            "Kemenche",
            "Khim",
            "Kobza",
            "Kokle",
            "Kokyū",
            "Komuz",
            "Kora",
            "Koto",
            "Kubing",
            "Kudyapi",
            "Kwitra",
            "Langeleik",
            "Laouto",
            "Laruan",
            "Laúd",
            "Lavta",
            "Leiqin",
            "Leona",
            "Lirone",
            "Liuqin",
            "Lokanga",
            "Lute",
            "Lute guitar",
            "Lyra",
            "Lyre",
            "Maguhu",
            "Mandobass",
            "Mandola",
            "Mandolin",
            "Mandolute",
            "Mandora",
            "Mandore",
            "Marovany",
            "Mejoranera",
            "Mexican vihuela",
            "Mohan veena",
            "Moraharpa",
            "Morin khuur",
            "Musical bow",
            "Nyckelharpa",
            "Octobass",
            "Oud",
            "Paqin",
            "Piano",
            "Pipa",
            "Piwancha",
            "Pochette",
            "Portuguese guitar",
            "Psaltery",
            "Qanun",
            "Qinqin",
            "Rabeca",
            "Rajão",
            "Ravanahatha",
            "Rebab",
            "Rebec",
            "Requinto jarocho",
            "Rubab",
            "Ruan",
            "Gaoyinruan",
            "Xiaoruan",
            "Zhongruan",
            "Daruan",
            "Diyinruan",
            "Rudra vina",
            "Sallameh",
            "Sanshin",
            "Santoor",
            "Sanxian",
            "Sarangi",
            "Šargija",
            "Sarod",
            "Saung",
            "Saw sam sai",
            "Se",
            "Seul",
            "Setar (lute)",
            "Shamisen",
            "Sintir",
            "Sitar",
            "Sitarla",
            "Surbahar",
            "Swarmandal",
            "Tamburica",
            "Tambur",
            "Tanpura",
            "Tar (lute)",
            "Tea chest bass",
            "Tembûr",
            "Theorbo",
            "Timple",
            "Tiple",
            "Tovshuur",
            "Tres",
            "Tres Cubano",
            "Tres Puerto Rico",
            "Tricordia",
            "Tro",
            "Trumpet marine/tromba marina",
            "Tsymbaly",
            "Tuhu",
            "Tzouras",
            "Ukulele",
            "Ukelin",
            "Valiha",
            "Veena",
            "Vichitra veena",
            "Vielle",
            "Vihuela",
            "Viola",
            "Violin",
            "Violone",
            "Violotta",
            "Walaycho",
            "Waldzither",
            "Washtub bass",
            "Whamola",
            "Wheelharp",
            "Xalam/Khalam",
            "Yaylı tambur",
            "Yangqin",
            "Yazheng",
            "Yehu",
            "Yelatáj chos woley",
            "Yueqin",
            "Zhongruan",
            "Zhonghu",
            "Zhu",
            "Zhengni",
            "Zhuihu",
            "Zither",
        ],
    },
    {
        "category": "electronics",
        "instruments": [
            "AlphaSphere",
            "Audiocubes",
            "Bass pedals",
            "Continuum Fingerboard",
            "Croix Sonore",
            "Denis d'or",
            "Dubreq stylophone",
            "Drum machine",
            "Eigenharp",
            "Electric guitar",
            "Electronic keyboard",
            "Electronic organ",
            "EWI",
            "Fingerboard synthesizer",
            "Hammond organ",
            "Jammer keyboard",
            "Keyboard",
            "Keytar",
            "Kraakdoos (cracklebox)",
            "Laser harp",
            "Mellotron",
            "MIDI keyboard",
            "Omnichord",
            "Ondes Martenot",
            "Otamatone",
            "Sampler",
            "Seaboard",
            "Skoog",
            "Synclavier",
            "Synthesizer",
            "Teleharmonium",
            "Tembûr",
            "Tenori-on",
            "Theremin",
            "Turntable",
        ],
    },
]



def test_music_genre_object(fake):
    test_genre_obj = fake.music_genre_object()
    assert isinstance(test_genre_obj, dict)
    assert "genre" in test_genre_obj.keys()
    assert "subgenres" in test_genre_obj.keys()


def test_music_genre(fake):
    test_genre = fake.music_genre()
    assert isinstance(test_genre, str)
    assert len(test_genre) > 0


def test_music_subgenre(fake):
    test_subgenre = fake.music_subgenre()
    assert isinstance(test_subgenre, str)
    assert len(test_subgenre) > 0


def test_music_instrument_object(fake):
    test_instrument_obj = fake.music_instrument_object()
    assert isinstance(test_instrument_obj, dict)
    assert "category" in test_instrument_obj.keys()
    assert "instruments" in test_instrument_obj.keys()


def test_music_instrument(fake):
    test_instrument = fake.music_instrument()
    assert isinstance(test_instrument, str)
    assert len(test_instrument) > 0


def test_music_instrument_category(fake):
    test_instrument_category = fake.music_instrument_category()
    assert isinstance(test_instrument_category, str)
    assert len(test_instrument_category) > 0



from random import choice
from faker.providers import BaseProvider
from .genres import genre_list
from .instruments import instrument_list


class MusicProvider(BaseProvider):
    """
    A Provider for music-related data.

    Typical use:
    >>> from faker import Faker
    >>> from faker_music import MusicProvider
    >>> fake = Faker()
    >>> fake.add_provider(MusicProvider)
    >>> fake.music_genre()
    >>> fake.music_subgenre()
    >>> etc...
    """

    def music_genre_object(self):
        """
        Returns a randomly-chosen genre dictionary. This is a
        dictionary whose first key is 'genre', a string;
        and whose second key is 'subgenres', a list of strings.

        Example:
        {
             "genre": "Metal",
             "subgenres": [
                 "Black Metal",
                 "Goth Metal",
                 "Thrash Metal"
             ]
        }
        """
        return choice(genre_list)

    def music_genre(self):
        """
        Returns a string representing a musical genre.
        """
        my_choice = choice(genre_list)
        return my_choice["genre"]

    def music_subgenre(self):
        """
        Returns a string representing a musical subgenre.
        """
        while True:
            my_choice = choice(genre_list)
            if len(my_choice["subgenres"]) == 0:
                continue
            return choice(my_choice["subgenres"])

    def music_instrument_object(self):
        """
        Returns a randomly-chosen instrument dictionary. This is a
        dictionary whose first key is 'category', a string;
        and whose second key, "instruments", refers to a list of
        instruments in that category.

        Example:
        {
             "category": "electronics",
             "instruments": [
                 "Drum machine",
                 "Electric piano",
                 "Synthesizer"
             ]
        }
        """
        return choice(instrument_list)

    def music_instrument(self):
        """
        Returns a musical instrument in string format.
        """
        my_choice = choice(instrument_list)
        return choice(my_choice["instruments"])

    def music_instrument_category(self):
        """
        Returns an instrument category in string format.
        """
        my_choice = choice(instrument_list)
        return my_choice["category"]



"""
Raw data for faker_music module (music.py) to mine from.
Data is presented in one big list of dicts, each dict
corresponding to a "genre object":
{
    "genre": "<genre_name>",
    "subgenres": [
        "<subgenre1>",
        "<subgenre2>",
        "<subgenre3>",
        ...
    ]
}

This data was harvested on 2021-05-14, from 
https://www.musicgenreslist.com/
Author maintains code to format copy/pasted data;
please ask for link to gist
"""

genre_list = [
    {
        "genre": "Alternative",
        "subgenres": [
            "Art Punk",
            "Alternative Rock",
            "Britpunk",
            "College Rock",
            "Crossover Thrash",
            "Crust Punk",
            "Emotional Hardcore",
            "Experimental Rock",
            "Folk Punk",
            "Goth",
            "Grunge",
            "Hardcore Punk",
            "Hard Rock",
            "Indie Rock",
            "Lo-fi",
            "Musique Concrète",
            "New Wave",
            "Progressive Rock",
            "Punk",
            "Shoegaze",
            "Steampunk",
        ],
    },
    {"genre": "Anime", "subgenres": []},
    {
        "genre": "Blues",
        "subgenres": [
            "Acoustic Blues",
            "African Blues",
            "Blues Rock",
            "Blues Shouter",
            "British Blues",
            "Canadian Blues",
            "Chicago Blues",
            "Classic Blues",
            "Classic Female Blues",
            "Contemporary Blues",
            "Contemporary R&B",
            "Country Blues",
            "Dark Blues",
            "Delta Blues",
            "Detroit Blues",
            "Doom Blues",
            "Electric Blues",
            "Folk Blues",
            "Gospel Blues",
            "Harmonica Blues",
            "Hill Country Blues",
            "Hokum Blues",
            "Jazz Blues",
            "Jump Blues",
            "Kansas City Blues",
            "Louisiana Blues",
            "Memphis Blues",
            "Modern Blues",
            "New Orlean Blues",
            "NY Blues",
            "Piano Blues",
            "Piedmont Blues",
            "Punk Blues",
            "Ragtime Blues",
            "Rhythm Blues",
            "Soul Blues",
            "St. Louis Blues",
            "Soul Blues",
            "Swamp Blues",
            "Texas Blues",
            "Urban Blues",
            "Vandeville",
            "West Coast Blues",
            "Zydeco",
        ],
    },
    {"genre": "Children’s Music", "subgenres": ["Lullabies", "Sing-Along", "Stories"]},
    {
        "genre": "Classical",
        "subgenres": [
            "Avant-Garde",
            "Ballet",
            "Baroque",
            "Cantata",
            "Chamber Music",
            "Chant",
            "Choral",
            "Classical Crossover",
            "Concerto",
            "Concerto Grosso",
            "Contemporary Classical",
            "Early Music",
            "Expressionist",
            "High Classical",
            "Impressionist",
            "Mass Requiem",
            "Medieval",
            "Minimalism",
            "Modern Composition",
            "Modern Classical",
            "Opera",
            "Oratorio",
            "Orchestral",
            "Organum",
            "Renaissance",
            "Romantic",
            "Romantic",
            "Sonata",
            "Symphonic",
            "Symphony",
            "Wedding Music",
        ],
    },
    {
        "genre": "Comedy",
        "subgenres": ["Novelty", "Parody Music", "Stand-up Comedy", "Vaudeville"],
    },
    {"genre": "Commercial", "subgenres": ["Jingles", "TV Themes"]},
    {
        "genre": "Country",
        "subgenres": [
            "Alternative Country",
            "Americana",
            "Australian Country",
            "Bakersfield Sound",
            "Bluegrass",
            "Blues Country",
            "Cajun Fiddle Tunes",
            "Christian Country",
            "Classic Country",
            "Close Harmony",
            "Contemporary Bluegrass",
            "Contemporary Country",
            "Country Gospel",
            "Country Pop",
            "Country Rap",
            "Country Rock",
            "Country Soul",
            "Cowpunk",
            "Dansband",
            "Honky Tonk",
            "Franco-Country",
            "Gulf and Western",
            "Hellbilly Music",
            "Honky Tonk",
            "Instrumental Country",
            "Lubbock Sound",
            "Nashville Sound",
            "Neotraditional Country",
            "Outlaw Country",
            "Progressive",
            "Psychobilly",
            "Punkabilly",
            "Red Dirt",
            "Sertanejo",
            "Texas County",
            "Traditional Bluegrass",
            "Traditional Country",
            "Truck-Driving Country",
            "Urban Cowboy",
            "Western Swing",
            "Zydeco",
        ],
    },
    {
        "genre": "Dance )",
        "subgenres": [
            "Club",
            "Breakcore",
            "Breakbeat",
            "Breakstep",
            "Brostep",
            "Chillstep",
            "Deep House",
            "Dubstep",
            "Eurodance",
            "Electro House",
            "Electroswing",
            "Exercise",
            "Future Garage",
            "Garage",
            "Glitch Hop",
            "Glitch Pop",
            "Grime",
            "Hardcore",
            "Hard Dance",
            "Hi-NRG",
            "Horrorcore",
            "House",
            "Jackin House",
            "Jungle",
            "Liquid Dub",
            "Regstep",
            "Speedcore",
            "Techno",
            "Trance",
            "Trap",
        ],
    },
    {"genre": "Disney", "subgenres": []},
    {
        "genre": "Easy Listening",
        "subgenres": [
            "Background",
            "Bop",
            "Elevator",
            "Furniture",
            "Lounge",
            "Middle of the Road",
            "Swing",
        ],
    },
    {
        "genre": "Electronic",
        "subgenres": [
            "2-Step",
            "8bit",
            "Ambient",
            "Asian Underground",
            "Bassline",
            "Chillwave",
            "Chiptune",
            "Crunk",
            "Downtempo",
            "Drum & Bass",
            "Electro",
            "Electro-swing",
            "Electroacoustic",
            "Electronica",
            "Electronic Rock",
            "Eurodance",
            "Hardstyle",
            "Hi-Nrg",
            "IDM/Experimental",
            "Industrial",
            "Trip Hop",
            "UK Garage",
        ],
    },
    {"genre": "Enka", "subgenres": []},
    {"genre": "French Pop", "subgenres": []},
    {
        "genre": "Folk Music",
        "subgenres": [
            "American Folk Revival",
            "Anti-Folk",
            "British Folk Revival",
            "Contemporary Folk",
            "Filk Music",
            "Freak Folk",
            "Indie Folk",
            "Industrial Folk",
            "Neofolk",
            "Progressive Folk",
            "Psychedelic Folk",
            "Sung Poetry",
            "Techno-Folk",
        ],
    },
    {"genre": "German Folk", "subgenres": []},
    {"genre": "German Pop", "subgenres": []},
    {"genre": "Fitness & Workout", "subgenres": []},
    {
        "genre": "Hip-Hop/Rap",
        "subgenres": [
            "Alternative Rap",
            "Avant-Garde",
            "Bounce",
            "Chap Hop",
            "Christian Hip Hop",
            "Conscious Hip Hop",
            "Country-Rap",
            "Crunkcore",
            "Cumbia Rap",
            "Dirty South",
            "East Coast",
            "Freestyle Rap",
            "G-Funk",
            "Gangsta Rap",
            "Golden Age",
            "Hardcore Rap",
            "Hip-Hop",
            "Hip Pop",
            "Hyphy",
            "Industrial Hip Hop",
            "Instrumental Hip Hop",
            "Jazz Rap",
            "Latin Rap",
            "Low Bap",
            "Lyrical Hip Hop",
            "Merenrap",
            "Midwest Hip Hop",
            "Motswako",
            "Nerdcore",
            "New Jack Swing",
            "New School Hip Hop",
            "Old School Rap",
            "Rap",
            "Turntablism",
            "Underground Rap",
            "West Coast Rap",
        ],
    },
    {
        "genre": "Holiday",
        "subgenres": [
            "Chanukah",
            "Christmas",
            "Christmas: Children’s",
            "Christmas: Classic",
            "Christmas: Classical",
            "Christmas: Comedy",
            "Christmas: Jazz",
            "Christmas: Modern",
            "Christmas: Pop",
            "Christmas: R&B",
            "Christmas: Religious",
            "Christmas: Rock",
            "Easter",
            "Halloween",
            "Holiday: Other",
            "Thanksgiving",
        ],
    },
    {"genre": "Indie Pop", "subgenres": []},
    {
        "genre": "Industrial",
        "subgenres": [
            "Aggrotech",
            "Coldwave",
            "Cybergrind",
            "Dark Electro",
            "Death Industrial",
            "Electro-Industrial",
            "Electronic Body Music",
            "Industrial Metal",
            "Industrial Rock",
            "Noise",
            "Witch House",
        ],
    },
    {
        "genre": "Inspirational – Christian & Gospel",
        "subgenres": [
            "CCM",
            "Christian Metal",
            "Christian Pop",
            "Christian Rap",
            "Christian Rock",
            "Classic Christian",
            "Contemporary Gospel",
            "Gospel",
            "Christian & Gospel",
            "Praise & Worship",
            "Qawwali",
            "Southern Gospel",
            "Traditional Gospel",
        ],
    },
    {"genre": "Instrumental", "subgenres": ["March"]},
    {"genre": "J-Pop", "subgenres": ["J-Rock", "J-Synth", "J-Ska", "J-Punk"]},
    {
        "genre": "Jazz",
        "subgenres": [
            "Acid Jazz",
            "Avant-Garde Jazz",
            "Bebop",
            "Big Band",
            "Blue Note",
            "Contemporary Jazz",
            "Cool",
            "Crossover Jazz",
            "Dixieland",
            "Ethio-jazz",
            "Fusion",
            "Gypsy Jazz",
            "Hard Bop",
            "Latin Jazz",
            "Mainstream Jazz",
            "Ragtime",
            "Smooth Jazz",
            "Trad Jazz",
            "Third Stream",
            "Jazz-Funk",
            "Free Jazz",
            "Modal Jazz",
        ],
    },
    {"genre": "K-Pop", "subgenres": []},
    {"genre": "Karaoke", "subgenres": []},
    {"genre": "Kayokyoku", "subgenres": []},
    {
        "genre": "Latin",
        "subgenres": [
            "Alternativo & Rock Latino",
            "Argentine tango",
            "Bachata",
            "Baithak Gana",
            "Baladas y Boleros",
            "Bolero",
            "Bossa Nova",
            "Brazilian",
            "Chicha",
            "Criolla",
            "Contemporary Latin",
            "Cumbia",
            "Flamenco",
            "Huayno",
            "Latin Jazz",
            "Mariachi",
            "Merengue Típico",
            "Nuevo Flamenco",
            "Pop Latino",
            "Portuguese fado",
            "Punta",
            "Punta Rock",
            "Ranchera",
            "Raíces",
            "Raison",
            "Reggaeton y Hip-Hop",
            "Regional Mexicano",
            "Salsa y Tropical",
            "Soca",
            "Son",
            "Tejano",
            "Timba",
            "Twoubadou",
            "Zouk",
        ],
    },
    {
        "genre": "Metal",
        "subgenres": [
            "Heavy Metal",
            "Speed Metal",
            "Thrash Metal",
            "Power Metal",
            "Death Metal",
            "Black Metal",
            "Pagan Metal",
            "Viking Metal",
            "Folk Metal",
            "Symphonic Metal",
            "Gothic Metal",
            "Glam Metal",
            "Hair Metal",
            "Doom Metal",
            "Groove Metal",
            "Industrial Metal",
            "Modern Metal",
            "Neoclassical Metal",
            "New Wave Of British Heavy Metal",
            "Post Metal",
            "Progressive Metal",
            "Avantgarde Metal",
            "Sludge",
            "Djent",
            "Drone",
            "Kawaii Metal",
            "Pirate Metal",
            "Nu Metal",
            "Neue Deutsche Härte",
            "Math Metal",
            "Crossover",
            "Grindcore",
            "Hardcore",
            "Metalcore",
            "Deathcore",
            "Post Hardcore",
            "Mathcore",
        ],
    },
    {
        "genre": "New Age",
        "subgenres": [
            "Ambient",
            "Environmental",
            "Healing",
            "Meditation",
            "Nature",
            "Relaxation",
            "Travel",
            "Yoga",
        ],
    },
    {"genre": "Opera", "subgenres": []},
    {
        "genre": "Pop",
        "subgenres": [
            "Adult Contemporary",
            "Arab Pop",
            "Baroque",
            "Britpop",
            "Bubblegum Pop",
            "Chamber Pop",
            "Chanson",
            "Christian Pop",
            "Classical Crossover",
            "Europop",
            "Dance Pop",
            "Dream Pop",
            "Electro Pop",
            "Iranian Pop",
            "Jangle Pop",
            "Latin Ballad",
            "Levenslied",
            "Louisiana Swamp Pop",
            "Mexican Pop",
            "Motorpop",
            "New Romanticism",
            "Orchestral Pop",
            "Pop Rap",
            "Popera",
            "Pop/Rock",
            "Pop Punk",
            "Power Pop",
            "Psychedelic Pop",
            "Schlager",
            "Soft Rock",
            "Sophisti-Pop",
            "Space Age Pop",
            "Sunshine Pop",
            "Surf Pop",
            "Synthpop",
            "Teen Pop",
            "Traditional Pop Music",
            "Turkish Pop",
            "Vispop",
            "Wonky Pop",
        ],
    },
    {"genre": "Post-Disco", "subgenres": ["Boogie", "Dance-pop"]},
    {
        "genre": "Progressive",
        "subgenres": [
            "Progressive House",
            "Progressive Breaks",
            "Progressive Drum & Bass",
            "Progressive Techno",
            "Trance",
        ],
    },
    {
        "genre": "R&B/Soul",
        "subgenres": [
            "Contemporary R&B",
            "Disco",
            "Doo Wop",
            "Funk",
            "Modern Soul",
            "Motown",
            "Neo-Soul",
            "Northern Soul",
            "Psychedelic Soul",
            "Quiet Storm",
            "Soul",
            "Soul Blues",
            "Southern Soul",
        ],
    },
    {
        "genre": "Reggae",
        "subgenres": [
            "2-Tone",
            "Dancehall",
            "Dub",
            "Roots Reggae",
            "Reggae Fusion",
            "Reggae en Español",
            "Lovers Rock",
            "Raggamuffin",
            "Ska",
        ],
    },
    {
        "genre": "Rock",
        "subgenres": [
            "Acid Rock",
            "Adult-Oriented Rock",
            "Afro Punk",
            "Adult Alternative",
            "Alternative Rock",
            "American Traditional Rock",
            "Anatolian Rock",
            "Arena Rock",
            "Art Rock",
            "Blues-Rock",
            "British Invasion",
            "Cock Rock",
            "Death Metal",
            "Doom Metal",
            "Glam Rock",
            "Gothic Metal",
            "Grind Core",
            "Hair Metal",
            "Hard Rock",
            "Math Metal",
            "Math Rock",
            "Metal",
            "Metal Core",
            "Noise Rock",
            "Jam Bands",
            "Post Punk",
            "Prog-Rock/Art Rock",
            "Progressive Metal",
            "Psychedelic",
            "Rock & Roll",
            "Rockabilly",
            "Roots Rock",
            "Singer/Songwriter",
            "Southern Rock",
            "Spazzcore",
            "Stoner Metal",
            "Surf",
            "Technical Death Metal",
            "Tex-Mex",
            "Thrash Metal",
            "Time Lord Rock  ~",
            "Trip-hop",
        ],
    },
    {
        "genre": "Singer/Songwriter",
        "subgenres": [
            "Alternative Folk",
            "Contemporary Folk",
            "Contemporary Singer/Songwriter",
            "Indie Folk",
            "Folk-Rock",
            "Love Song",
            "New Acoustic",
            "Traditional Folk",
        ],
    },
    {
        "genre": "Soundtrack",
        "subgenres": [
            "Foreign Cinema",
            "Movie Soundtrack",
            "Musicals",
            "Original Score",
            "Soundtrack",
            "TV Soundtrack",
        ],
    },
    {"genre": "Spoken Word", "subgenres": []},
    {
        "genre": "Tejano",
        "subgenres": [
            "Chicano",
            "Classic",
            "Conjunto",
            "Conjunto Progressive",
            "New Mex",
            "Tex-Mex",
        ],
    },
    {
        "genre": "Tex-Mex",
        "subgenres": [
            "Chicano",
            "Classic",
            "Conjunto",
            "Conjunto Progressive",
            "New Mex",
            "Tex-Mex",
        ],
    },
    {
        "genre": "Vocal",
        "subgenres": [
            "A cappella",
            "Barbershop",
            "Cantique",
            "Doo-wop",
            "Gregorian Chant",
            "Standards",
            "Traditional Pop",
            "Vocal Jazz",
            "Vocal Pop",
        ],
    },
    {
        "genre": "World",
        "subgenres": [
            "Africa",
            "Asia",
            "Australia",
            "Cajun",
            "Calypso",
            "Caribbean",
            "Carnatic",
            "Celtic",
            "Celtic Folk",
            "Contemporary Celtic",
            "Coupé-décalé  – Congo",
            "Dangdut",
            "Drinking Songs",
            "Drone",
            "Europe",
            "France",
            "Hawaii",
            "Japan",
            "Klezmer",
            "Mbalax  – Senegal",
            "Middle East",
            "North America",
            "Ode",
            "Piphat  – Thailand",
            "Polka",
            "Soca",
            "South Africa",
            "South America",
            "Southeast Asia",
            "Traditional Celtic",
            "Worldbeat",
            "Zydeco",
        ],
    },
]
